/*
 * Parameter.h
 *
 *  Created on: Apr 30, 2012
 *      Author: Brenda Javornik (e-mail: brendaj (at) cora.nwra.com)
 */

#ifndef PARAMETER_H_
#define PARAMETER_H_

#include "utilities.h"
#include "lambda.h"
#include "FileMapAndParameters.h"

/** \addtogroup Parameters Looping parameters (lambda, mu, sigma, and nu)
 *  @{
 */

typedef struct ParameterTypeNode {
	double currentValue;
	double currentStep;
	LambdaSet parameterRange;
	struct ParameterTypeNode *next;
	void (*increment) (struct ParameterTypeNode *);  ///< Public pointer to function to increment
	BOOLEAN (*more) (struct ParameterTypeNode *); ///< Public pointer to function returns true if more sigma steps; false if done
} ParameterType;

void incrementParameter(ParameterType *pt);
BOOLEAN moreParameters(ParameterType *pt);
void addParameter(LambdaSet ls);
void incrementSigma(ParameterType *pt);

// Currently, there are three parameters, mu, sigma, and nu
#define NUM_PARAMETERS MAX_ALPHA

/*
// Global variables
// Parameters is a pointer to the head of a linked list of parameters.
// Mu, Nu, and Sigma are pointers to individual elements/nodes of the
// parameter list.
ParameterType *Parameters = NULL;
ParameterType *Nu = NULL;
ParameterType *Mu = NULL;
ParameterType *Sigma = NULL;
*/

ParameterType *getSigma();
void setSigma(ParameterType *pt);

void setSigmaStep(int steps);

ParameterType *getParameters();

ParameterType *getMu();
void setMu(ParameterType *pt);

ParameterType *getNu();
void setNu(ParameterType *pt);

void initLoopParameters(InputParms inputParms);

void destroyParameters(ParameterType *pt);

/** @} */

#endif /* PARAMETER_H_ */
